eapol/eapol_framework/eapol_symbian/am/type/mschapv2/symbian/plugin/inc/EapMsChapV2DbUtils.h
branchRCL_3
changeset 46 c74b3d9f6b9e
parent 45 bad0cc58d154
--- a/eapol/eapol_framework/eapol_symbian/am/type/mschapv2/symbian/plugin/inc/EapMsChapV2DbUtils.h	Tue Aug 31 15:16:37 2010 +0300
+++ b/eapol/eapol_framework/eapol_symbian/am/type/mschapv2/symbian/plugin/inc/EapMsChapV2DbUtils.h	Wed Sep 01 12:23:57 2010 +0100
@@ -16,7 +16,7 @@
 */
 
 /*
-* %version: 8.1.8 %
+* %version: 10 %
 */
 
 #ifndef _EAPMSCHAPV2DBUTILS_H_
@@ -30,10 +30,21 @@
 
 // LOCAL CONSTANTS
 
-// For EAP-MsChapV2 private database. Database will be in the private folder of EAP-server (20026FCB).
-// The maximum length of database name is 0x40 (KDbMaxName), which is defined in d32dbms.h.
+#ifdef SYMBIAN_SECURE_DBMS
+// For EAP MSCHAPV2 secure database.
+// Full path is not needed. The database eapmsmhapv2.dat will be saved in the 
+// data cage path for DBMS. So it will be in "\private\100012a5\eapmsmhapv2.dat" in C: drive.
+// The maximum length of database name is 0x40 (KDbMaxName) , which is defined in d32dbms.h.
+
+_LIT(KDatabaseName, "c:eapmschapv2.dat");
 
-_LIT(KEapMsChapV2DatabaseName, "eapmschapv2.dat");
+_LIT(KSecureUIDFormat, "SECURE[102072e9]"); // For the security policy.
+
+#else
+
+_LIT(KDatabaseName, "c:\\system\\data\\eapmschapv2.dat");
+
+#endif // #ifdef SYMBIAN_SECURE_DBMS
 
 _LIT(KMsChapV2TableName, "eapmschapv2");
 
@@ -43,8 +54,8 @@
 public:
 	
 	static void OpenDatabaseL(
-		RDbNamedDatabase& aDatabase,
-		RFs& aFileServerSession,
+		RDbNamedDatabase& aDatabase, 
+		RDbs& aSession, 
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
@@ -88,6 +99,7 @@
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
+
 };
 
 #endif // _EAPMSCHAPV2DBUTILS_H_